Package 'rpublons'

Title: Client for Publons.com
Description: Extract review information information from Publons <https://publons.com>.
Authors: Thomas J. Leeper [aut, cre] (ORCID: <https://orcid.org/0000-0003-4097-6326>)
Maintainer: Thomas J. Leeper <[email protected]>
License: MIT + file LICENSE
Version: 0.1.1
Built: 2026-05-08 06:00:55 UTC
Source: https://github.com/favstats/rpublons

Help Index


rpublons

Description

Client for Publons.com

Usage

publons(
  verb = c("GET", "POST", "HEAD", "OPTIONS"),
  endpoint,
  body = NULL,
  query = NULL,
  researcher_id = NULL,
  ...,
  base_url = "https://publons.com/api/v2/",
  token = Sys.getenv("PUBLONS_TOKEN"),
  username = Sys.getenv("PUBLONS_USERNAME"),
  password = Sys.getenv("PUBLONS_PASSWORD")
)

publons_auth()

Arguments

verb

A character string containing an HTTP request verb.

endpoint

A character string containing an API endpoint.

body

Optionally, a request body.

query

Optionally, a list containing HTTP query arguments.

base_url

A character string specifying the base URL for the API.

token

A character string containing a Publons API token. By default, taken from environment variables.

username

A character string, containing a Publons username, passed to publons_auth if token is missing. This is used to generate an API token, if needed.

password

A character string, containing a Publons password, passed to publons_auth if token is missing. This is used to generate an API token, if needed.

Details

Extract review information information from Publons https://publons.com. This is currently a low-level client that handles authorization but no high-level functionality.

Author(s)

Thomas J. Leeper <[email protected]>

References

Publons API v2 Documentation

Examples

## Not run: 
  # retrieve and store API token
  publons_auth("myusername", "mypassword")
  
  # get list of academics
  publons("GET", "academic/")
  
  # get academics by institution
  publons("GET", "academic/", query = list(institution = "Harvard University"))
  
  # get a specific academic by ORCiD
  publons("GET", paste0("academic/", "0000-0003-4097-6326"))
  
  # get reviews for a specific academic by ORCiD
  publons("GET", "academic/review/", 
          query = list(academic = "0000-0003-4097-6326"))
  
  # get a specific review
  publons("GET", paste0("academic/review/", "YK8zafgo"))
  

## End(Not run)